@@ -1,7 +1,7 @@
 package App::GitHubUtils;
 
 our $DATE = '2018-10-09'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,11 @@ use Log::ger;
 
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Utilities related to GitHub',
+};
+
 $SPEC{create_the_github_repo} = {
     v => 1.1,
     summary => 'Create github repo',
@@ -69,7 +74,7 @@ sub create_the_github_repo {
 }
 
 1;
-# ABSTRACT: Create github repo
+# ABSTRACT: Utilities related to GitHub
 
 __END__
 
@@ -79,11 +84,11 @@ __END__
 
 =head1 NAME
 
-App::GitHubUtils - Create github repo
+App::GitHubUtils - Utilities related to GitHub
 
 =head1 VERSION
 
-This document describes version 0.002 of App::GitHubUtils (from Perl distribution App-GitHubUtils), released on 2018-10-09.
+This document describes version 0.003 of App::GitHubUtils (from Perl distribution App-GitHubUtils), released on 2018-10-09.
 
 =head1 DESCRIPTION
 
